@@ -1,70 +1,117 @@
-from pylangacq.util import CLITIC, get_lemma_from_mor
-from pylangacq.dependency import DependencyGraph
+from typing import List
+
+from pylangacq.dependency import _DependencyGraph
 
 
-# noinspection PyPep8Naming
-def get_MLUm(tagged_sents, pos_to_ignore=None):
-    """Mean length of utterance (MLU) in morphemes"""
-    # *tagged_sents* already filtered for the desired participant like 'CHI'
-    total_utterance_count = 0
-    total_morpheme_count = 0
+_CLITIC = "CLITIC"
 
-    for tagged_sent in tagged_sents:
-        total_utterance_count += 1
-
-        for tagged_word in tagged_sent:
-            pos = tagged_word[1]
-            morph = tagged_word[2]
-
-            if pos_to_ignore and pos in pos_to_ignore:
-                continue
-
-            total_morpheme_count += 1
-            total_morpheme_count += morph.count("-")
-            total_morpheme_count += morph.count("~")
-
-    if total_utterance_count:
-        return total_morpheme_count / total_utterance_count
-    else:
-        return 0
+_POS_TO_IGNORE = frozenset({"", "!", "+...", "0", "?", "BEG"})
+_WORDS_TO_IGNORE = frozenset(
+    {
+        "",
+        "!",
+        "+...",
+        ".",
+        ",",
+        "?",
+        "‡",
+        "„",
+        "0",
+        _CLITIC,
+    }
+)
 
 
-# noinspection PyPep8Naming
-def get_MLUw(sents, words_to_ignore=None):
-    """Mean length of utterance (MLU) in words"""
-    # *sents* are already filtered for the desired participant like 'CHI'
-    total_utterance_count = 0
-    total_word_count = 0
+def _get_lemma_from_mor(mor):
+    """Extract lemma from ``mor``.
 
-    for sent in sents:
-        total_utterance_count += 1
+    Parameters
+    ----------
+    mor : tuple(str, str, str)
 
-        for word in sent:
-            if words_to_ignore and word in words_to_ignore:
-                continue
-            total_word_count += 1
-
-    if total_utterance_count:
-        return total_word_count / total_utterance_count
-    else:
-        return 0
+    Returns
+    -------
+    str
+    """
+    lemma, _, _ = mor.partition("-")
+    lemma, _, _ = lemma.partition("&")
+    return lemma
 
 
-# noinspection PyPep8Naming
-def get_TTR(word_freq_dict, words_to_ignore=None):
-    """Type-token ratio (TTR)"""
-    # *word_freq_dict* already filtered for the desired participant like 'CHI'
-    if words_to_ignore:
-        word_freq_dict = {
-            word: freq
-            for word, freq in word_freq_dict.items()
-            if word not in words_to_ignore
-        }
-    return len(word_freq_dict) / sum(word_freq_dict.values())
+def _get_mlum(tagged_sents) -> List[float]:
+    result = []
+
+    if not tagged_sents:
+        return result
+
+    for tagged_sents_for_file in tagged_sents:
+        if not tagged_sents_for_file:
+            result.append(0.0)
+            continue
+
+        morpheme_counts_for_file = []
+        for tagged_sent in tagged_sents_for_file:
+            morpheme_count = 0
+            for word in tagged_sent:
+                if word.pos in _POS_TO_IGNORE:
+                    continue
+                morpheme_count += 1
+                if type(word.mor) == str:
+                    morpheme_count += word.mor.count("-")
+                    morpheme_count += word.mor.count("~")
+            morpheme_counts_for_file.append(morpheme_count)
+
+        if morpheme_counts_for_file:
+            result.append(sum(morpheme_counts_for_file) / len(morpheme_counts_for_file))
+        else:
+            result.append(0.0)
+
+    return result
 
 
-# noinspection PyPep8Naming
-def get_IPSyn(tagged_sents):
+def _get_mluw(sents) -> List[float]:
+    result = []
+
+    if not sents:
+        return result
+
+    for sents_for_file in sents:
+        if not sents_for_file:
+            result.append(0.0)
+            continue
+
+        word_counts_for_file = []
+        for sent in sents_for_file:
+            word_count = sum(1 for word in sent if word not in _WORDS_TO_IGNORE)
+            word_counts_for_file.append(word_count)
+
+        if word_counts_for_file:
+            result.append(sum(word_counts_for_file) / len(word_counts_for_file))
+        else:
+            result.append(0.0)
+
+    return result
+
+
+def _get_ttr(word_freq_dicts) -> List[float]:
+    result_by_files = []
+    for word_freq in word_freq_dicts:
+        filtered = {w: f for w, f in word_freq.items() if w not in _WORDS_TO_IGNORE}
+        try:
+            result_by_files.append(len(filtered) / sum(filtered.values()))
+        except ZeroDivisionError:
+            result_by_files.append(0.0)
+    return result_by_files
+
+
+def _get_ipsyn(tagged_sents) -> List[int]:
+    result_by_files = []
+    for tagged_sents_for_file in tagged_sents:
+        result_by_files.append(_get_ipsyn_for_file(tagged_sents_for_file))
+    return result_by_files
+
+
+def _get_ipsyn_for_file(tagged_sents) -> int:
     """Index of Productive Syntax (IPSyn)"""
     if len(tagged_sents) > 100:
         tagged_sents = tagged_sents[:100]
@@ -224,8 +271,8 @@ def get_IPSyn(tagged_sents):
             if scoring_board_stop[item]:
                 break
 
-            sent_graph = DependencyGraph(tagged_sent)
-            if sent_graph.faulty():
+            sent_graph = _DependencyGraph(tagged_sent)
+            if sent_graph.faulty:
                 continue
 
             item_function(sent_graph)
@@ -238,10 +285,10 @@ def get_IPSyn(tagged_sents):
         """
         N1: Proper, mass, or count noun
         """
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             pos = graph.node[i]["pos"]
 
-            if pos.startswith("N:") or pos == "N":
+            if pos.startswith("n:") or pos == "n":
                 scoring_board["N1"] += 1
 
             if turn_off_scoring_board("N1"):
@@ -253,10 +300,10 @@ def get_IPSyn(tagged_sents):
         """
         N2: Pronoun or prolocative, excluding modifiers
         """
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             pos = graph.node[i]["pos"]
 
-            if pos.startswith("PRO") and pos != "PRO:POSS:DET":
+            if pos.startswith("pro") and pos != "pro:poss:det":
                 scoring_board["N2"] += 1
 
             if turn_off_scoring_board("N2"):
@@ -268,10 +315,10 @@ def get_IPSyn(tagged_sents):
         """
         N3: Modifier, including adjectives, possessives, and quantifiers
         """
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             pos = graph.node[i]["pos"]
 
-            if pos in {"PRO:POSS:DET", "ADJ", "QN"}:
+            if pos in {"pro:poss:det", "adj", "qn"}:
                 scoring_board["N3"] += 1
 
             if turn_off_scoring_board("N3"):
@@ -283,15 +330,15 @@ def get_IPSyn(tagged_sents):
         """
         N4: Two-word NP: nominal preceded by article or modifier
         """
-        if not graph.number_of_nodes() > 2:
+        if not graph.n_nodes() > 2:
             return
 
-        for i in range(1, graph.number_of_nodes() - 1):
+        for i in range(1, graph.n_nodes() - 1):
             pos1 = graph.node[i]["pos"]
             pos2 = graph.node[i + 1]["pos"]
 
-            if pos1 in {"PRO:POSS:DET", "ADJ", "QN"} and (
-                pos2.startswith("N:") or pos2 == "N"
+            if pos1 in {"pro:poss:det", "adj", "qn"} and (
+                pos2.startswith("n:") or pos2 == "n"
             ):
                 scoring_board["N4"] += 1
 
@@ -304,14 +351,14 @@ def get_IPSyn(tagged_sents):
         """
         N5: Article, used before a noun (Also credit: N4)
         """
-        if not graph.number_of_nodes() > 2:
+        if not graph.n_nodes() > 2:
             return
 
-        for i in range(1, graph.number_of_nodes() - 1):
+        for i in range(1, graph.n_nodes() - 1):
             pos1 = graph.node[i]["pos"]
             pos2 = graph.node[i + 1]["pos"]
 
-            if pos1 == "DET" and (pos2.startswith("N:") or pos2 == "N"):
+            if pos1 == "det" and (pos2.startswith("n:") or pos2 == "n"):
                 scoring_board["N5"] += 1
                 add_one_point_if_needed("N4")
 
@@ -324,18 +371,18 @@ def get_IPSyn(tagged_sents):
         """
         N6: Two-word NP (as in N4) after verb or preposition (Also credit: N4)
         """
-        if not graph.number_of_nodes() > 3:
+        if not graph.n_nodes() > 3:
             return
 
-        for i in range(1, graph.number_of_nodes() - 2):
+        for i in range(1, graph.n_nodes() - 2):
             pos1 = graph.node[i]["pos"]
             pos2 = graph.node[i + 1]["pos"]
             pos3 = graph.node[i + 2]["pos"]
 
             if (
-                pos2 in {"PRO:POSS:DET", "ADJ", "QN"}
-                and (pos3.startswith("N:") or pos3 == "N")
-                and (pos1 in {"V", "PREP"})
+                pos2 in {"pro:poss:det", "adj", "qn"}
+                and (pos3.startswith("n:") or pos3 == "n")
+                and (pos1 in {"v", "prep"})
             ):
                 scoring_board["N6"] += 1
                 add_one_point_if_needed("N4")
@@ -349,7 +396,7 @@ def get_IPSyn(tagged_sents):
         """
         N7: Plural suffix
         """
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             mor = graph.node[i]["mor"]
 
             if "-PL" in mor:
@@ -364,18 +411,18 @@ def get_IPSyn(tagged_sents):
         """
         N8: Two-word NP (as in N4) before verb (Also credit: N4)
         """
-        if not graph.number_of_nodes() > 3:
+        if not graph.n_nodes() > 3:
             return
 
-        for i in range(1, graph.number_of_nodes() - 2):
+        for i in range(1, graph.n_nodes() - 2):
             pos1 = graph.node[i]["pos"]
             pos2 = graph.node[i + 1]["pos"]
             pos3 = graph.node[i + 2]["pos"]
 
             if (
-                pos1 in {"PRO:POSS:DET", "ADJ", "QN"}
-                and (pos2.startswith("N:") or pos2 == "N")
-                and (pos3 == "V")
+                pos1 in {"pro:poss:det", "adj", "qn"}
+                and (pos2.startswith("n:") or pos2 == "n")
+                and (pos3 == "v")
             ):
                 scoring_board["N8"] += 1
                 add_one_point_if_needed("N4")
@@ -389,18 +436,18 @@ def get_IPSyn(tagged_sents):
         """
         N9: Three-word NP (Det/Mod+Mod+N) (Also credit: N4)
         """
-        if not graph.number_of_nodes() > 3:
+        if not graph.n_nodes() > 3:
             return
 
-        for i in range(1, graph.number_of_nodes() - 2):
+        for i in range(1, graph.n_nodes() - 2):
             pos1 = graph.node[i]["pos"]
             pos2 = graph.node[i + 1]["pos"]
             pos3 = graph.node[i + 2]["pos"]
 
             if (
-                (pos1 in {"PRO:POSS:DET", "ADJ", "QN"})
-                and (pos2 in {"ADJ", "QN"})
-                and (pos3.startswith("N:") or pos3 == "N")
+                (pos1 in {"pro:poss:det", "adj", "qn"})
+                and (pos2 in {"adj", "qn"})
+                and (pos3.startswith("n:") or pos3 == "n")
             ):
                 scoring_board["N9"] += 1
                 add_one_point_if_needed("N4")
@@ -414,17 +461,17 @@ def get_IPSyn(tagged_sents):
         """
         N10: Adverb modifying adjective or nominal (Also credit: V8)
         """
-        if not graph.number_of_nodes() > 2:
+        if not graph.n_nodes() > 2:
             return
 
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             pos = graph.node[i]["pos"]
 
-            if pos == "ADV":
+            if pos == "adv":
                 for j in graph.edge[i].keys():
                     pos_of_head = graph.node[j]["pos"]
 
-                    if pos_of_head in {"ADJ", "N"}:
+                    if pos_of_head in {"adj", "n"}:
                         scoring_board["N10"] += 1
                         add_one_point_if_needed("V8")
                         break
@@ -438,10 +485,10 @@ def get_IPSyn(tagged_sents):
         """
         N11: Any other bound morpheme on N or adjective
         """
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             pos = graph.node[i]["pos"]
 
-            if pos in {"N", "ADJ"} or pos.startswith("N:"):
+            if pos in {"n", "adj"} or pos.startswith("n:"):
                 mor = graph.node[i]["mor"]
                 mor = mor.replace("-PL", "")
 
@@ -457,10 +504,10 @@ def get_IPSyn(tagged_sents):
         """
         V1: Verb
         """
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             pos = graph.node[i]["pos"]
 
-            if pos == "V":
+            if pos == "v":
                 scoring_board["V1"] += 1
 
             if turn_off_scoring_board("V1"):
@@ -472,10 +519,10 @@ def get_IPSyn(tagged_sents):
         """
         V2: Particle or Preposition
         """
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             pos = graph.node[i]["pos"]
 
-            if pos == "PREP":
+            if pos == "prep":
                 scoring_board["V2"] += 1
 
             if turn_off_scoring_board("V2"):
@@ -487,7 +534,7 @@ def get_IPSyn(tagged_sents):
         """
         V3: Prepositional phrase (Prep + NP) (Also credit: V2)
         """
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             for j in graph.edge[i].keys():
 
                 if graph.edge[i][j]["rel"] == "POBJ":
@@ -503,12 +550,12 @@ def get_IPSyn(tagged_sents):
         """
         V4: Copula linking two nominals (Also credit: V1)
         """
-        if not graph.number_of_nodes() > 3:
+        if not graph.n_nodes() > 3:
             return
 
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             pos = graph.node[i]["pos"]
-            if pos != "COP":
+            if pos != "cop":
                 continue
 
             subject = False
@@ -520,7 +567,7 @@ def get_IPSyn(tagged_sents):
 
                 if graph.edge[dep][head]["rel"] == "SUBJ" and not graph.node[dep][
                     "pos"
-                ].endswith("WH"):
+                ].endswith("wh"):
                     subject = True
                 elif graph.edge[dep][head]["rel"] == "PRED":
                     predicate = True
@@ -538,7 +585,7 @@ def get_IPSyn(tagged_sents):
         """
         V5: Catenative (pseudo-auxiliary) preceding a verb
         """
-        if not graph.number_of_nodes() > 2:
+        if not graph.n_nodes() > 2:
             return
 
         pseudo_aux = {
@@ -558,9 +605,9 @@ def get_IPSyn(tagged_sents):
             "better",
         }
 
-        for i in range(1, graph.number_of_nodes() - 1):
+        for i in range(1, graph.n_nodes() - 1):
             pos2 = graph.node[i + 1]["pos"]
-            if pos2 != "V":
+            if pos2 != "v":
                 continue
 
             word1 = graph.node[i]["word"]
@@ -577,13 +624,13 @@ def get_IPSyn(tagged_sents):
         """
         V6: Auxiliary be, do, have in VP (Also credit: V5)
         """
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             pos = graph.node[i]["pos"]
             mor = graph.node[i]["mor"]
-            lemma = get_lemma_from_mor(mor)
+            lemma = _get_lemma_from_mor(mor)
 
-            if (pos == "AUX" and not mor.startswith("wi")) or (
-                lemma == "do" and pos == "MOD"
+            if (pos == "aux" and not mor.startswith("wi")) or (
+                lemma == "do" and pos == "mod"
             ):
                 scoring_board["V6"] += 1
                 add_one_point_if_needed("V5")
@@ -597,7 +644,7 @@ def get_IPSyn(tagged_sents):
         """
         V7: Progressive suffix
         """
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             mor = graph.node[i]["mor"]
 
             if mor.endswith("PRESP"):
@@ -612,10 +659,10 @@ def get_IPSyn(tagged_sents):
         """
         V8: Adverbs
         """
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             pos = graph.node[i]["pos"]
 
-            if pos == "ADV":
+            if pos == "adv":
                 scoring_board["V8"] += 1
 
             if turn_off_scoring_board("V8"):
@@ -627,15 +674,15 @@ def get_IPSyn(tagged_sents):
         """
         V9: Modal preceding verb (Also credit: V5)
         """
-        if not graph.number_of_nodes() > 2:
+        if not graph.n_nodes() > 2:
             return
 
-        for i in range(1, graph.number_of_nodes() - 1):
+        for i in range(1, graph.n_nodes() - 1):
             pos = graph.node[i]["pos"]
             word = graph.node[i]["word"]
             pos2 = graph.node[i + 1]["pos"]
 
-            if pos.startswith("MOD") and pos2 == "V" and word != CLITIC:
+            if pos.startswith("mod") and pos2 == "v" and word != _CLITIC:
                 scoring_board["V9"] += 1
                 add_one_point_if_needed("V5")
 
@@ -648,7 +695,7 @@ def get_IPSyn(tagged_sents):
         """
         V10: Third person singular present tense suffix
         """
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             mor = graph.node[i]["mor"]
 
             if "-3S" in mor:
@@ -665,10 +712,10 @@ def get_IPSyn(tagged_sents):
         """
         past_tense_modals = {"could", "did", "might", "would", "woudn't"}
 
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             pos = graph.node[i]["pos"]
 
-            if pos != "MOD":
+            if pos != "mod":
                 continue
 
             if graph.node[i]["word"] in past_tense_modals:
@@ -684,7 +731,7 @@ def get_IPSyn(tagged_sents):
         """
         V12: Regular past tense suffix
         """
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             mor = graph.node[i]["mor"]
 
             if "-PAST" in mor and "-PASTP" not in mor:
@@ -699,9 +746,9 @@ def get_IPSyn(tagged_sents):
         """
         V13: Past tense auxiliary (Also credit V6)
         """
-        aux_pos = {"AUX", "MOD"}
+        aux_pos = {"aux", "mod"}
 
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             mor = graph.node[i]["mor"]
             pos = graph.node[i]["pos"]
 
@@ -718,11 +765,11 @@ def get_IPSyn(tagged_sents):
         """
         V14: Medial adverb (Also credit V8)
         """
-        for i in range(2, graph.number_of_nodes() - 1):
+        for i in range(2, graph.n_nodes() - 1):
             # note the possible values of i for "medial" (not 1st or last word)
 
             pos = graph.node[i]["pos"]
-            if pos == "ADV":
+            if pos == "adv":
                 scoring_board["V14"] += 1
                 add_one_point_if_needed("V8")
 
@@ -736,13 +783,13 @@ def get_IPSyn(tagged_sents):
         V15: Copula, modal, or auxiliary for emphasis or ellipsis
         (uncontractible context) (Also credit V4, V6, V9, V11, V13, V16)
         """
-        if not graph.number_of_nodes() > 2:
+        if not graph.n_nodes() > 2:
             return
 
-        for i in range(1, graph.number_of_nodes() - 1):
+        for i in range(1, graph.n_nodes() - 1):
             pos1 = graph.node[i]["pos"]
 
-            if pos1 not in {"COP", "AUX", "MOD"}:
+            if pos1 not in {"cop", "aux", "mod"}:
                 continue
 
             mor2 = graph.node[i + 1]["mor"]
@@ -765,11 +812,11 @@ def get_IPSyn(tagged_sents):
         """
         V16: Past tense copula (Also credit V4)
         """
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             pos = graph.node[i]["pos"]
             mor = graph.node[i]["mor"]
 
-            if pos.startswith("COP") and "PAST" in mor:
+            if pos.startswith("cop") and "PAST" in mor:
                 scoring_board["V16"] += 1
                 add_one_point_if_needed("V4")
 
@@ -783,7 +830,7 @@ def get_IPSyn(tagged_sents):
         Q1: Intonationally marked question
         Automatically score 2 points if child earns 2 points on Q4 and/or Q8
         """
-        final_word = graph.node[graph.number_of_nodes() - 1]["word"]
+        final_word = graph.node[graph.n_nodes() - 1]["word"]
         if final_word != "?":
             return
 
@@ -805,7 +852,7 @@ def get_IPSyn(tagged_sents):
         """
         # needs work here
         # currently only testing for wh-pronoun alone
-        final_word = graph.node[graph.number_of_nodes() - 1]["word"]
+        final_word = graph.node[graph.n_nodes() - 1]["word"]
         if final_word != "?":
             return
 
@@ -813,7 +860,7 @@ def get_IPSyn(tagged_sents):
         if first_word not in {"what", "why", "how", "which", "where", "when"}:
             return
 
-        if graph.number_of_nodes() > 2:
+        if graph.n_nodes() > 2:
             scoring_board["Q2"] += 1
 
         if turn_off_scoring_board("Q2"):
@@ -827,10 +874,10 @@ def get_IPSyn(tagged_sents):
         neg = no(t), can't, don't
         X = NP, VP, PP, Adj, Adv, etc.
         """
-        if not graph.number_of_nodes() > 2:
+        if not graph.n_nodes() > 2:
             return
 
-        for i in range(1, graph.number_of_nodes() - 1):
+        for i in range(1, graph.n_nodes() - 1):
             word1 = graph.node[i]["word"]
             mor2 = graph.node[i + 1]["mor"]
 
@@ -851,9 +898,9 @@ def get_IPSyn(tagged_sents):
         Q4: Initial wh-pronoun followed by verb
         (if child earns 2 points for Q8, score 2 points to *both* Q1 and Q2)
         """
-        if not graph.number_of_nodes() > 2:
+        if not graph.n_nodes() > 2:
             return
-        final_word = graph.node[graph.number_of_nodes() - 1]["word"]
+        final_word = graph.node[graph.n_nodes() - 1]["word"]
         if final_word != "?":
             return
 
@@ -863,7 +910,7 @@ def get_IPSyn(tagged_sents):
 
         root = graph.edges()[1]
 
-        if graph.node[root]["pos"] == "V":
+        if graph.node[root]["pos"] == "v":
             scoring_board["Q4"] += 1
 
         if turn_off_scoring_board("Q4"):
@@ -878,7 +925,7 @@ def get_IPSyn(tagged_sents):
         """
         Q5: Negative morpheme between subject and verb (Also credit: Q3)
         """
-        if not graph.number_of_nodes() > 3:
+        if not graph.n_nodes() > 3:
             return
 
         for dep, head in graph.edges().items():
@@ -896,7 +943,7 @@ def get_IPSyn(tagged_sents):
                 continue
 
             for i in range(dep + 1, head):  # head > dep
-                if graph.node[i]["pos"] == "NEG":
+                if graph.node[i]["pos"] == "neg":
                     scoring_board["Q5"] += 1
                     add_one_point_if_needed("Q3")
                     break
@@ -910,16 +957,16 @@ def get_IPSyn(tagged_sents):
         """
         Q6: Wh-question with inverted modal, copula, or auxiliary
         """
-        if not graph.number_of_nodes() > 2:
+        if not graph.n_nodes() > 2:
             return
 
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             if scoring_board_stop["Q6"]:
                 break
 
             pos = graph.node[i]["pos"]
 
-            if pos not in {"COP", "MOD", "AUX"}:
+            if pos not in {"cop", "mod", "aux"}:
                 continue
 
             for dep, head in graph.edges().items():
@@ -932,7 +979,7 @@ def get_IPSyn(tagged_sents):
 
                 pos_of_dep = graph.node[dep]["pos"]
 
-                if pos_of_dep == "ADV:WH":
+                if pos_of_dep == "adv:wh":
                     scoring_board["Q6"] += 1
 
                 if turn_off_scoring_board("Q6"):
@@ -944,13 +991,13 @@ def get_IPSyn(tagged_sents):
         """
         Q7: Negation of copula, modal, or auxiliary (Also credit Q5)
         """
-        if not graph.number_of_nodes() > 2:
+        if not graph.n_nodes() > 2:
             return
 
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             pos = graph.node[i]["pos"]
 
-            if pos not in {"MOD", "COP", "AUX"}:
+            if pos not in {"mod", "cop", "aux"}:
                 continue
 
             for dep, head in graph.edges().items():
@@ -959,7 +1006,7 @@ def get_IPSyn(tagged_sents):
 
                 pos_of_dep = graph.node[dep]["pos"]
 
-                if pos_of_dep == "NEG":
+                if pos_of_dep == "neg":
                     scoring_board["Q7"] += 1
                     add_one_point_if_needed("Q5")
 
@@ -974,14 +1021,14 @@ def get_IPSyn(tagged_sents):
         (if child earns 2 points for Q8, score 2 points to *both* Q1 and Q2)
         """
         # test may need to be checked/improved
-        if not graph.number_of_nodes() > 2:
+        if not graph.n_nodes() > 2:
             return
 
-        final_word = graph.node[graph.number_of_nodes() - 1]["word"]
+        final_word = graph.node[graph.n_nodes() - 1]["word"]
         if final_word != "?":
             return
 
-        for i in range(1, graph.number_of_nodes() - 1):
+        for i in range(1, graph.n_nodes() - 1):
             if scoring_board_stop["Q8"]:
                 break
 
@@ -992,7 +1039,7 @@ def get_IPSyn(tagged_sents):
             else:
                 wh_test = "dummy"
 
-            if pos1 in {"COP", "MOD", "AUX"} and not wh_test.endswith("WH"):
+            if pos1 in {"cop", "mod", "aux"} and not wh_test.endswith("wh"):
 
                 for j in graph.edge[i + 1].keys():
                     rel2 = graph.edge[i + 1][j]["rel"]
@@ -1014,7 +1061,7 @@ def get_IPSyn(tagged_sents):
         Q9: Why, when, which, whose
         """
         wh = {"why", "when", "which", "whose"}
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             word = graph.node[i]["word"]
             if word in wh:
                 scoring_board["Q9"] += 1
@@ -1028,15 +1075,15 @@ def get_IPSyn(tagged_sents):
         """
         Q10: Tag question
         """
-        if not graph.number_of_nodes() > 2:
+        if not graph.n_nodes() > 2:
             return
 
         # Part 1: test for ending "okay ?", "ok ?", "right ?"
-        final_word = graph.node[graph.number_of_nodes() - 1]["word"]
+        final_word = graph.node[graph.n_nodes() - 1]["word"]
         if final_word != "?":
             return
 
-        second_final_word = graph.node[graph.number_of_nodes() - 2]["word"]
+        second_final_word = graph.node[graph.n_nodes() - 2]["word"]
         if second_final_word in {"okay", "ok", "right"}:
             scoring_board["Q10"] += 1
 
@@ -1044,10 +1091,10 @@ def get_IPSyn(tagged_sents):
             return
 
         # Part 2: test for "normal" tag questions
-        good_pos = {"COP NEG PRO ?", "COP PRO ?"}
+        good_pos = {"cop neg pro ?", "cop pro ?"}
         collate = []
 
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             collate.append(graph.node[i]["pos"])
 
         test = " ".join(collate)
@@ -1065,7 +1112,7 @@ def get_IPSyn(tagged_sents):
         """
         S1: Two-word combination
         """
-        if not graph.number_of_nodes() > 2:
+        if not graph.n_nodes() > 2:
             return
 
         scoring_board["S1"] += 1
@@ -1079,7 +1126,7 @@ def get_IPSyn(tagged_sents):
         """
         S2: Subject-verb sequence (Also credit: S1)
         """
-        if not graph.number_of_nodes() > 2:
+        if not graph.n_nodes() > 2:
             return
 
         for dep, head in graph.edges().items():
@@ -1093,7 +1140,7 @@ def get_IPSyn(tagged_sents):
 
             head_pos = graph.node[head]["pos"]
 
-            if head_pos == "V":
+            if head_pos == "v":
                 scoring_board["S2"] += 1
                 add_one_point_if_needed("S1")
 
@@ -1106,7 +1153,7 @@ def get_IPSyn(tagged_sents):
         """
         S3: Verb-object sequence (Also credit: S1)
         """
-        if not graph.number_of_nodes() > 2:
+        if not graph.n_nodes() > 2:
             return
 
         for dep, head in graph.edges().items():
@@ -1120,7 +1167,7 @@ def get_IPSyn(tagged_sents):
 
             head_pos = graph.node[head]["pos"]
 
-            if head_pos == "V":
+            if head_pos == "v":
                 scoring_board["S3"] += 1
                 add_one_point_if_needed("S1")
 
@@ -1133,13 +1180,13 @@ def get_IPSyn(tagged_sents):
         """
         S4: Subject-verb-object sequence (Also credit: S2 & S3)
         """
-        if not graph.number_of_nodes() > 3:
+        if not graph.n_nodes() > 3:
             return
 
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             pos = graph.node[i]["pos"]
 
-            if pos != "V":
+            if pos != "v":
                 continue
 
             has_subject = False
@@ -1169,10 +1216,10 @@ def get_IPSyn(tagged_sents):
         """
         S5: Conjunction (any)
         """
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             pos = graph.node[i]["pos"]
 
-            if pos == "CONJ":
+            if pos == "conj":
                 scoring_board["S5"] += 1
 
             if turn_off_scoring_board("S5"):
@@ -1184,7 +1231,7 @@ def get_IPSyn(tagged_sents):
         """
         S6: Sentence with two VPs
         """
-        if not graph.number_of_nodes() > 4:
+        if not graph.n_nodes() > 4:
             return
 
         all_edges = graph.edges()
@@ -1194,7 +1241,7 @@ def get_IPSyn(tagged_sents):
         for dep, head in all_edges.items():
             head_pos = graph.node[head]["pos"]
 
-            if head_pos != "V":
+            if head_pos != "v":
                 continue
 
             verbs.append(head)
@@ -1212,18 +1259,18 @@ def get_IPSyn(tagged_sents):
         """
         S7: Conjoined phrases (Also credit: S5)
         """
-        if not graph.number_of_nodes() > 3:
+        if not graph.n_nodes() > 3:
             return
 
         # for all trios, we want the middle word to be CONJ (for pos)
         # and the first+final words are *not* punctuation (for mor)
-        for i in range(1, graph.number_of_nodes() - 2):
+        for i in range(1, graph.n_nodes() - 2):
             mor1 = graph.node[i]["mor"]
             pos2 = graph.node[i + 1]["pos"]
             mor3 = graph.node[i + 2]["mor"]
 
             punctuations = {"", "beg", "end"}
-            if pos2 == "CONJ" and mor1 not in punctuations and mor3 not in punctuations:
+            if pos2 == "conj" and mor1 not in punctuations and mor3 not in punctuations:
                 scoring_board["S7"] += 1
                 add_one_point_if_needed("S5")
 
@@ -1237,7 +1284,7 @@ def get_IPSyn(tagged_sents):
         S8: Infinitive without catenative, marked with "to"
         (Also credit: S6 & V5)
         """
-        if not graph.number_of_nodes() > 3:
+        if not graph.n_nodes() > 3:
             return
 
         # we want:
@@ -1247,7 +1294,7 @@ def get_IPSyn(tagged_sents):
         for dep, head in graph.edges().items():
             pos = graph.node[dep]["pos"]
 
-            if pos != "INF":
+            if pos != "inf":
                 continue
 
             inf_verb = head
@@ -1288,7 +1335,7 @@ def get_IPSyn(tagged_sents):
                 if test_head != target_head:
                     continue
 
-                if graph.node[test_dep]["pos"] == "V":
+                if graph.node[test_dep]["pos"] == "v":
                     scoring_board["S9"] += 1
                     break
 
@@ -1304,11 +1351,11 @@ def get_IPSyn(tagged_sents):
         """
         exceptions = {"and", "or", "then"}
 
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             word = graph.node[i]["word"]
             pos = graph.node[i]["pos"]
 
-            if pos == "CONJ" and word not in exceptions:
+            if pos == "conj" and word not in exceptions:
                 scoring_board["S10"] += 1
                 add_one_point_if_needed("S5")
 
@@ -1321,7 +1368,7 @@ def get_IPSyn(tagged_sents):
         """
         S11: Propositional complement (Also credit S6)
         """
-        if not graph.number_of_nodes() > 3:
+        if not graph.n_nodes() > 3:
             return
 
         subject_count = 0
@@ -1331,7 +1378,7 @@ def get_IPSyn(tagged_sents):
 
             if (
                 graph.edge[dep][head]["rel"] == "SUBJ"
-                and graph.node[dep]["word"] != CLITIC
+                and graph.node[dep]["word"] != _CLITIC
             ):
                 subject_count += 1
                 subject_count_increment = True
@@ -1350,7 +1397,7 @@ def get_IPSyn(tagged_sents):
         S12: Conjoined sentences (except for imperatives, will usually have
         subj+predicate in each clause) (Also credit: S6, S5)
         """
-        if not graph.number_of_nodes() > 3:
+        if not graph.n_nodes() > 3:
             return
 
         for dep, head in graph.edges().items():
@@ -1361,7 +1408,7 @@ def get_IPSyn(tagged_sents):
 
             rel = graph.edge[dep][head]["rel"]
 
-            if rel == "CONJ" and graph.node[head]["pos"] == "V":
+            if rel == "CONJ" and graph.node[head]["pos"] == "v":
                 scoring_board["S12"] += 1
                 add_one_point_if_needed("S6")
                 add_one_point_if_needed("S5")
@@ -1375,12 +1422,12 @@ def get_IPSyn(tagged_sents):
         """
         S13: Wh-clause (Also credit S6) (If also infinitive, credit S8 or S17)
         """
-        if not graph.number_of_nodes() > 3:
+        if not graph.n_nodes() > 3:
             return
 
         for dep, head in graph.edges().items():
             dep_pos = graph.node[dep]["pos"]
-            if not dep_pos.endswith("WH"):
+            if not dep_pos.endswith("wh"):
                 continue
 
             inf = False
@@ -1412,7 +1459,7 @@ def get_IPSyn(tagged_sents):
         """
         S14: Bitransitive predicate (Also credit S3)
         """
-        if not graph.number_of_nodes() > 3:
+        if not graph.n_nodes() > 3:
             return
 
         dep_head_pairs_for_obj = []
@@ -1440,15 +1487,11 @@ def get_IPSyn(tagged_sents):
         """
         S15: Sentence with 3 or more VPs (Also credit S6)
         """
-        if not graph.number_of_nodes() > 3:
+        if not graph.n_nodes() > 3:
             return
 
         number_of_verbs = sum(
-            [
-                1
-                for i in range(1, graph.number_of_nodes())
-                if graph.node[i]["pos"] == "V"
-            ]
+            1 for i in range(1, graph.n_nodes()) if graph.node[i]["pos"] == "v"
         )
 
         if number_of_verbs > 2:
@@ -1468,7 +1511,7 @@ def get_IPSyn(tagged_sents):
         # (from Sagae et al 2005 ACL)
         # add one criterion: "and" is not one of the intervening words
 
-        if not graph.number_of_nodes() > 3:
+        if not graph.n_nodes() > 3:
             return
 
         for dep, head in graph.edges().items():
@@ -1497,7 +1540,7 @@ def get_IPSyn(tagged_sents):
         """
         S17: Infinitive clause: new subject. (Also credit: S8)
         """
-        if not graph.number_of_nodes() > 3:
+        if not graph.n_nodes() > 3:
             return
 
         # example of a hit case: "he wants me to go"
@@ -1507,7 +1550,7 @@ def get_IPSyn(tagged_sents):
             word = graph.node[dep]["word"]
             pos = graph.node[dep]["pos"]
 
-            if word != "to" or pos != "INF":
+            if word != "to" or pos != "inf":
                 continue
 
             inf_verb = head  # "go" in the example
@@ -1532,10 +1575,10 @@ def get_IPSyn(tagged_sents):
         """
         S18: Gerund (Also credit: V7)
         """
-        for i in range(1, graph.number_of_nodes()):
+        for i in range(1, graph.n_nodes()):
             pos = graph.node[i]["pos"]
 
-            if pos == "N:GERUND":
+            if pos == "n:gerund":
                 scoring_board["S18"] += 1
                 add_one_point_if_needed("V7")
 
@@ -1551,14 +1594,14 @@ def get_IPSyn(tagged_sents):
         # might need more work
         # for now: check if CONJ precedes two SUBJ's
 
-        conj_position = graph.number_of_nodes()  # decrement if CONJ is found
+        conj_position = graph.n_nodes()  # decrement if CONJ is found
         subj_position_list = []
 
         for dep, head in graph.edges().items():
             pos = graph.node[dep]["pos"]
             rel = graph.edge[dep][head]["rel"]
 
-            if pos == "CONJ" and dep < conj_position:
+            if pos == "conj" and dep < conj_position:
                 conj_position = dep
 
             if rel == "SUBJ":
